<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use Carbon\Carbon;
use App\Models\User;
use App\Models\CourseSubject;
use App\Models\UserStudentProfilePlan;
use App\Models\Course;
use App\Models\AppUrls;

class UserController extends Controller
{

    public function apilogin(Request $request)
    {
        $credentials = $request->only('email', 'password');

        if (Auth::attempt($credentials)) {
            $user = Auth::user();
            $token = $user->createToken('AuthToken')->accessToken;
            return response()->json(['token' => $token], 200);
        } else {
            return response()->json(['error' => 'Unauthorised'], 401);
        }
    }



    public function loginOrRegister(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'device_id' => 'required',
            'email' => 'required',
            'profile_pic' => 'required',
        ]);

        if ($validator->fails()) {
            return response()->json(['error' => $validator->errors()->first()], 401);
        }
        $user = User::where('email', $request->email)->first();
        //dd($user);        
        if (!$user) {
            $usernew = new User();
            $usernew->name = $request->name;
            $usernew->device_id = $request->device_id;
            $usernew->email = $request->email;
            $usernew->profile_pic = $request->profile_pic;
            $usernew->last_active_profile = 'PROFILE_ONE';
             $usernew->profile_one_type = 'STUDENT';

            $beforeAtSymbol = substr($request->email, 0, strpos($request->email, '@'));
            $res = str_replace( array( '.', '_' ), '', $beforeAtSymbol);
             if (strlen($res) === 1) {
                $cha = substr($res, 0, 1).'ZX';
            }
            elseif (strlen($res) === 2) {
                $cha = substr($res, 0, 2).'X';
            }
           elseif (strlen($res) === 2) {
                $cha = substr($res, 0, 2);
            } elseif (strlen($res) === 3) {
                $cha = substr($res, 0, 3);
            } else {
                $cha = substr($res, 0, 3);
            }

            $usernew->referral_id = rand(1000,9999).'-'.strtoupper($cha).'-'.rand(100,999);
            $usernew->save();

            $userdata = User::where('email', $usernew->email)->first();
            //dd($userdata);
            $token = $userdata->createToken('AuthToken')->accessToken;
            
            // Step 2: Modify the attributes
            $userdata->token = $token;

            // Step 3: Save the changes to the database
            $userdata->save();

            $user = User::where('email', $request->email)->first();
            $data['user_blocked'] = ($user->user_blocked == 'true')?true:false;
            $data['device_id_exists'] = true;
            $data['device_id'] = $user->device_id;
            $data['is_onboarded'] = ($user->is_onboarded == 'true')?true:false;
            $data['user_email'] = $user->email;
            $data['photo_url'] = $user->profile_pic;
            $data['user_name'] = $user->name;
            $data['last_active_profile'] = '';
            $data['profile_type'] = '';
            $data['course_id'] = '';
            $data['board'] = '';
            $data['class'] = '';
            $data['stream'] = '';
            $data['medium'] = '';
        } else if($user->profile_one_type == 'STUDENT') {
            $user->device_id = $request->device_id;
            $user->save();
            $token = $user->createToken('AuthToken')->accessToken;
            $data['user_blocked'] = ($user->user_blocked == 'true')?true:false;
            $data['device_id_exists'] = true;
            $data['device_id'] = $request->device_id;
            $data['is_onboarded'] = ($user->is_onboarded == 'true')?true:false;
            $data['user_email'] = $user->email;
            $data['photo_url'] = $user->profile_pic;
            $data['user_name'] = $user->name;
            $data['last_active_profile'] = $user->last_active_profile;

            $studentprofileplan = UserStudentProfilePlan::select('course_id')->where(['user_email'=>$request->email,'profile_number'=>$user->last_active_profile])->orderBy('id','DESC')->first();
            //dd($studentprofileplan);
            if($studentprofileplan){
                if($user->profile_one == 'true'){
                    $data['profile_type'] = $user->profile_one_type;
                }else{
                    $data['profile_type'] = $user->profile_two_type;
                }
                $data['course_id'] = $studentprofileplan->course_id;
                $cousedata = Course::with('board','class','streamlist','mediumlist')->where(['C_ID'=>$studentprofileplan->course_id])->first();
                //dd($cousedata);
                if($cousedata){
                    $data['board'] = $cousedata->board->board_name;
                    $data['class'] = $cousedata->class->class_name;
                    $data['stream'] = (isset($cousedata->streamlist) && !empty($cousedata->streamlist->name))?$cousedata->streamlist->name:'NA';
                    $data['medium'] = (isset($cousedata->mediumlist) && !empty($cousedata->mediumlist->name))?$cousedata->mediumlist->name:'NA';
                }else{
                    return response()->json(['error' => 'Course id does not exist!'], 200);
                }
                
            }else{
                $data['profile_type'] = '';
                $data['course_id'] = '';
                $data['board'] = '';
                $data['class'] = '';
                $data['stream'] = '';
                $data['medium'] = '';
            }
        }  else if($user->profile_one_type == 'TEACHER'){
            return response()->json(['error' => 'User already exists as Teacher'], 200);
        }
        if($user->profile_one == 'true' && $user->profile_two == 'true'){
            $user->both_profile_created = 'true';
            $data['both_profile_created'] = true;
        }else{
            $user->both_profile_created = 'false';
            $data['both_profile_created'] = false;
        }        
        $data['token'] = $token;
        $user->token = $token;
        if($user->save()){
            return response()->json([            
                'message' => 'success',
                'user_data' => $data
            ]);
        }else{
            return response()->json(['error' => 'Unauthorised'], 401);
        }
        //$user = User::where('email', $request->email)->first();

        // Generate a new token for the user
        
    }
    
    
     public function get_app_url(){
        // dd($request);
        try{
           $app_urls = AppUrls::get();
                        if($app_urls){
                                $data['message'] = 'success';
                            foreach($app_urls as $key=>$value){
                                $data['app_url_data'][$key]['id'] = $value->id;
                                $data['app_url_data'][$key]['title'] = $value->title;
                                $data['app_url_data'][$key]['url'] = $value->url;
                                $data['app_url_data'][$key]['active'] = $value->active;
                                $data['app_url_data'][$key]['menu_display'] = $value->menu_display;
                            }
                        }else{
                            $data = array();
                        }
                        return response()->json([
                            'data' => $data,
                        ], 200);
                    
        }catch (\Exception $e) {
            return response()->json(['message' => $e->getMessage()], 401);
        }

    }





    public function get_subject_data()
    {
        // $courses = Course::get();
        // $courses = Course::with('Board')->get();
        $courses = CourseSubject::with(['CourseSubjectChapter', 'ChapterSeperator','BannerTemplate'])->get();
        // foreach($courses as $key=>$coursevalue){
        //     //dd($coursevalue);
        //     $coursedata['courses'][$key]['board']['boardId'] = $coursevalue->board->Board_Id;
        //     $coursedata['courses'][$key]['board']['boardOrder'] = $coursevalue->board->board_order;
        //     $coursedata['courses'][$key]['board']['boardName'] = $coursevalue->board->board_name;

        //     $coursedata['courses'][$key]['grade']['boardId'] = $coursevalue->class->board_id;
        //     $coursedata['courses'][$key]['grade']['classId'] = $coursevalue->class->class_id;
        //     $coursedata['courses'][$key]['grade']['ClassOrder'] = $coursevalue->class->class_order;
        //     $coursedata['courses'][$key]['grade']['className'] = $coursevalue->class->class_name;

        //     $coursedata['courses'][$key]['stream'] = $coursevalue->streamlist->name;
        //     $coursedata['courses'][$key]['medium'] = $coursevalue->mediumlist->name;
        //     $coursedata['courses'][$key]['courseId'] = $coursevalue->C_ID;
        // }                                                                          
        // dd($coursedata);
        return response()->json([                
            'message' => 'Success',
            'data' => $courses,                
        ]);
    }


}