<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use App\Models\AppUrls;
use Dotenv\Util\Str;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;


class AppUrlsController extends Controller {

    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        $appUrls = AppUrls::orderby('id', 'desc')->get();
        return view('backend.appurls.index', compact('appUrls'));
    }

    public function create()
    {
        return view('backend.appurls.create');
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'title' => 'required',
            'url' => 'required',
        ]);
        
        if ($validator->fails()) {
            return redirect()->back()
            ->with('error', $validator->errors()->first());
        }

        $userSave = AppUrls::create([
            'title' => $request['title'],
            'url' => $request['url'],
        ]);

        return redirect()->route('backend.appurls.index')
            ->with('success', 'Url successfully created');
    }

    public function edit($id){
        $appUrl = AppUrls::find($id);
        return view('backend.appurls.edit', compact('appUrl'));
    }

    public function update(Request $request, AppUrls $id)
    {
        //dd($request);
        $validator = Validator::make($request->all(), [
            'title' => 'required',
            'url' => 'required',
        ]);
        if ($validator->fails()) {
            return redirect()->route('backend.appurls.index')
            ->with('error', $validator->errors()->first());
        }

        $id->title = $request->title;
        $id->url = $request->url;
        $id->save();

        return redirect()->route('backend.appurls.index')
            ->with('success', 'Url successfully updated!');
    }

    public function status(AppUrls $id, $status)
    {
        // dd($appUrl);
        if ($id) {
            $id->active = $status;
            $id->save();
            return redirect()->back()
                ->with('success', 'Url status successfully updated');
        }
    }

    public function delete(AppUrls $id)
    {
        //dd($id); 
        if ($id) {            
            $id->delete();
            return redirect()->back()
                ->with('success', 'Url deleted');
        }
    }

    public function updateMenuDisplay(AppUrls $id)
    {
        if ($id) {
            $id->menu_display = !$id->menu_display;
            $id->save();
            return redirect()->back()
                ->with('success', 'Menu display updated successfully');
        }
    }
}