<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Board;
use Illuminate\Support\Facades\Validator;

class BoardController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        $board = Board::orderby('id', 'desc')->get();
        return view('backend.board.index', compact('board'));
    }
    
    public function create()
    {
        return view('backend.board.create');
    }

    public function store(Request $request)
    {
        // dd($request);
        $validator = Validator::make($request->all(), [
            'board_order' => 'required',
            'board_name' => 'required',
        ]);
        if ($validator->fails()) {
            return redirect()->route('backend.board.index')
            ->with('error', $validator->errors()->first());
        }

        $userSave = Board::create([
            'board_order' => $request['board_order'],
            'Board_Id' => $request['Board_Id'],
            'board_name' => $request['board_name']
        ]);


        return redirect()->route('backend.board.index')
            ->with('success', 'Board successfully created');
    }

    public function edit(Board $id){
        //dd($id);
        return view('backend.board.edit', compact('id'));
    }

    public function update(Request $request, Board $id)
    {
        //dd($request);
        $validator = Validator::make($request->all(), [
            'board_order' => 'required',
            'board_name' => 'required'
        ]);
        
        if ($validator->fails()) {
            return redirect()->route('backend.board.index')
            ->with('error', $validator->errors()->first());
        }

        $id->board_order = $request->board_order;
        $id->Board_Id = $request->Board_Id;
        $id->board_name = $request->board_name;
        $id->save();

        return redirect()->route('backend.board.index')
            ->with('success', 'Board successfully updated');
    }    

    public function status(Board $id, $status)
    {
        //dd($id);
        if ($id) {
            $id->status = $status;
            $id->save();
            return redirect()->route('backend.board.index')
                ->with('success', 'Board status successfully updated');
        }
        return view('backend.board.index');
    }

    public function delete(Board $id)
    {
        //dd($id);
        if ($id) {            
            $id->delete();
            return redirect()->route('backend.board.index')
                ->with('success', 'Board deleted');
        }
        return view('backend.board.index');
    }

    public function board_order($id)
    {
        $count = Board::where('board_order',$id)->count();
        return $count;
    }


    public function board_Id($id)
    {
        $count = Board::where('Board_Id',$id)->count();
        return $count;
    }
}
