<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Board;
use App\Models\Classes;
use Illuminate\Support\Facades\Validator;

class ClassesController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        $classes = Classes::orderby('id', 'desc')->get();
        return view('backend.classes.index', compact('classes'));
    }
    
    public function create($id)
    {
        $boards = Board::select('board_id')->first();
        return view('backend.classes.create', compact('boards','id'));
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'class_order' => 'required',
            'class_name' => 'required',
            'board_id' => 'required',
        ]);
        
        if ($validator->fails()) {
            return redirect()->back()
            ->with('error', $validator->errors()->first());
        }

        $userSave = Classes::create([
            'class_order' => $request['class_order'],
            'class_id' => $request['class_id'],

            'class_name' => $request['class_name'],
            'board_id' => $request['board_id'],
        ]);

        return redirect()->route('backend.class.boardclasses',$request['board_id'])
            ->with('success', 'Class successfully created');
    }

    public function edit(Classes $id){
        $boards = Board::select('board_id', 'board_name')->orderby('id', 'asc')->get();
        return view('backend.classes.edit', compact('id','boards'));
    }

    public function update(Request $request, Classes $id)
    {
        //dd($request);
        $validator = Validator::make($request->all(), [
            'class_order' => 'required',
            'class_name' => 'required',
        ]);
        if ($validator->fails()) {
            return redirect()->route('backend.class.index')
            ->with('error', $validator->errors()->first());
        }

        $id->class_order = $request->class_order;
        $id->class_id = $request->class_id;

        $id->class_name = $request->class_name;
        // $id->stream = $request->stream;
        // $id->medium = $request->medium;
        $id->save();

        return redirect()->route('backend.class.boardclasses',$request['board_id'])
            ->with('success', 'Class successfully update!');
    }
    

    public function status(Classes $id, $status)
    {
        if ($id) {
            $id->status = $status;
            $id->save();
            return redirect()->back()
                ->with('success', 'Class status successfully updated');
        }
    }

    public function delete(Classes $id)
    {
        //dd($id);
        if ($id) {            
            $id->delete();
            return redirect()->back()
                ->with('success', 'Class deleted');
        }
    }

    public function boardclasses($id){
        //dd($id);
        $boards = Board::select('board_id')->where('board_id',$id)->first();
        $classes = Classes::where('board_id',$id)->orderby('id', 'desc')->get();
        return view('backend.classes.board_classes', compact('classes','boards'));
    }

    public function class_order($board_id,$order){
        $count = Classes::where(['board_id'=>$board_id,'class_order'=>$order])->count();
        return $count;
    }


    public function class_Id($id){
        $count = Classes::where('class_id',$id)->count();
        return $count;
    }

}
