<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Course;
use App\Models\CourseSubject;
use App\Models\Board;
use App\Models\Classes;
use App\Models\Medium;
use App\Models\Stream;
use App\Models\BannerTemplate;
use App\Models\CoursePlan;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\DB;

class CourseController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        $course = Course::with('board','class','streamlist','mediumlist')->orderby('id', 'desc')->get();
        return view('backend.course.index', compact('course'));
    }
    
    public function create()
    {
        $mediums = Medium::select('id','name')->where('status','1')->orderby('id', 'desc')->get();
        $strems = Stream::select('id','name')->where('status','1')->orderby('id', 'desc')->get();
        $boards = Board::select('board_id','board_name')->orderby('id', 'desc')->get();
        $classes = Classes::select('class_id','class_name')->orderby('id', 'desc')->get();
        return view('backend.course.create',compact('boards','classes','mediums','strems'));
    }

    public function store(Request $request)
    {
        //dd($request);
        $validator = Validator::make($request->all(), [
            'C_ID'     => 'required',
            'board_id' => 'required',
            'class_id' => 'required',
        ]);
        if ($validator->fails()) {
            return redirect()->route('backend.course.index')
            ->with('error', $validator->errors()->first());
        }

        $userSave = Course::create([
            'C_ID' => $request['C_ID'],
            'board_id' => $request['board_id'],
            'class_id' => $request['class_id'],
            'stream' => $request['stream'],
            'medium' => $request['medium'],
        ]);

        return redirect()->route('backend.course.index')
            ->with('success', 'Course successfully created');
    }

    public function edit(Course $id){
        //dd($id);

        $mediums = Medium::select('id','name')->where('status','1')->orderby('id', 'desc')->get();
        $strems = Stream::select('id','name')->where('status','1')->orderby('id', 'desc')->get();

        $boards = Board::select('board_id','board_name')->orderby('id', 'desc')->get();
        $classes = Classes::select('class_id','class_name')->where('board_id', $id->board_id)->orderby('id', 'desc')->get();
        return view('backend.course.edit', compact('id','boards','classes','mediums','strems'));
    }

    public function update(Request $request, Course $id)
    {
        //dd($request);
        $validator = Validator::make($request->all(), [
            'board_id' => 'required',
            'class_id' => 'required',
        ]);
        if ($validator->fails()) {
            return redirect()->route('backend.course.index')
            ->with('error', $validator->errors()->first());
        }

        $id->board_id = $request->board_id;
        $id->class_id = $request->class_id;
        $id->stream = $request->stream;
        $id->medium = $request->medium;
        $id->save();

        return redirect()->route('backend.course.index')
            ->with('success', 'Course successfully created');
    }
    

    public function status(Course $id, $status)
    {
        //dd($id);
        if ($id) {
            $id->status = $status;
            $id->save();
            return redirect()->route('backend.course.index')
                ->with('success', 'Course status successfully updated');
        }
        return view('backend.course.index');
    }

    public function delete(Course $id)
    {
        //dd($id);
        if ($id) {
            $id->delete();                
            return redirect()->route('backend.course.index')
            ->with('success', 'Course deleted');
            
        }
        return view('backend.course.index');
    }

    public function get_class($id){

        //dd($id);
        $classes = Classes::select('class_id','class_name')->where('board_id',$id)->orderby('id', 'desc')->get();
        return $classes;

    }

    public function course_uniqueid($id){
        $count = Course::where('C_ID',$id)->count();
        return $count;
    }

}
