<?php

namespace App\Http\Controllers\backend;

use App\Helper\Common;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Auth;
use \Spatie\Permission\Models\Permission;
use \Illuminate\Support\Facades\DB;

class RoleController extends Controller
{
    public function index()
    {   
        if (!Auth::guard('web')->user()->can('manage roles')) {
            abort(401);
        }

        $roles = Role::where('name', '!=', env('SUPERADMIN_NAME'))->paginate(10);
        return view('backend.roles.index', compact('roles'));
    }

    public function show()
    {
        
    }

    public function create()
    {
        if (!Auth::guard('web')->user()->can('manage roles')) {
            abort(401);
        }
        $permissions = Permission::all();
        $permission_id[]='';
        return view('backend.roles.create',compact('permissions','permission_id'));
    }

    public function store(Request $request)
    {
        $customMessages = [
            'name.unique' => 'Role already exists!'
        ];

        $this->validate($request, [
            'name' => 'required|max:255|unique:roles'
        ], $customMessages);

        $data = $request->only(['name']);

        $data['name'] = ucwords($request->name);
        $data['guard_name'] = 'web';
        $role = Role::firstOrCreate($data);
        //dd($role);
        if (isset($request['permission_id'])) {
            foreach ((array) $request['permission_id'] as $permission_id) {
                $roleHasPermissions[] = [
                    'role_id' => $role['id'],
                    'permission_id' => $permission_id
                ];
            }
        }
        //dd($roleHasPermissions);
        if ( isset($roleHasPermissions) && count($roleHasPermissions)) {
            DB::table('role_has_permissions')->where('role_id',$role['id'])->delete();
            DB::table('role_has_permissions')->insert($roleHasPermissions);
        }
        return redirect()->route('backend.role.index')->with('success', 'Role Created Successfully!');
    }

    public function edit(Role $role)
    {
        if (!Auth::guard('web')->user()->can('manage roles')) {
            abort(401);
        }
        $permissions = Permission::all();
        $rolehaspermission = DB::table('role_has_permissions')->where('role_id',$role['id'])->get();
        //dd($rolehaspermission);
        $permission_id[]='';
        foreach ($rolehaspermission as $key => $value) {
            $permission_id[]=$value->permission_id;
        }
        //dd($permission_id);
        return view('backend.roles.edit', compact('role','permissions','permission_id'));
    }

    public function update(Request $request, Role $role)
    {
        $customMessages = [
            'name.unique' => 'Role already exists!'
        ];

        $this->validate($request, [
            'name' => 'required|max:255|unique:roles,name,' . $role->id
        ], $customMessages);

        $data = $request->only(['name']);
        $role->update($data);
        if (isset($request['permission_id'])) {
            foreach ((array) $request['permission_id'] as $permission_id) {
                $roleHasPermissions[] = [
                    'role_id' => $role['id'],
                    'permission_id' => $permission_id
                ];
            }
        }
        if (isset($roleHasPermissions) && count($roleHasPermissions)) {
            DB::table('role_has_permissions')->where('role_id',$role['id'])->delete();
            DB::table('role_has_permissions')->insert($roleHasPermissions);
        }
        return redirect()->route('backend.role.index')->with('success', 'Role Updated Successfully!');
    }

    public function destroy(Role $role)
    {
        $role->delete();
        return redirect()->route('backend.role.index')->with('success', 'Role Deleted Successfully!');
    }

    public function search(Request $request)
    {
        if (!Auth::guard('web')->user()->can('manage roles')) {
            abort(401);
        }
        $roles = Role::where('name', '!=', env('SUPERADMIN_NAME'))
            ->where('name', 'LIKE', "%" . $request->search . "%")
            ->paginate(10);

        return view('backend.roles.includes.listing', compact('roles'));
    }
}
