<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Course;
use App\Models\BannerTemplate;
use App\Models\CourseSubject;
use App\Models\CoursePlan;
use App\Models\AdditionalCourse;
use App\Models\Referrer;
use App\Models\Referee;
use App\Models\SubjectTemplate;
use App\Models\SubjectCategory;
use App\Models\PlanType;
use App\Models\CourseSubjectChapter;
use App\Models\Pdf;
use App\Models\AdditionalCourseTemplate;
use App\Models\AdditionalCourseSubject;
use App\Models\AdditionalCourseSubjectChapter;
use App\Models\AdditionalCourseSubjectChapterPdf;
use App\Models\ChapterSeperator;
use App\Models\AdditionalBanner;
use App\Models\AdditionalSeperator;
use App\Models\HelpUrl;
use App\Models\CourseReferralLink;

use Illuminate\Support\Facades\Validator;

class StudentDashboardController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index($id)
    {
        $topbanners = BannerTemplate::where('course_id', $id)->where('banner_type', 'top')->orderby('banner_order', 'ASC')->get();
        $bottombanners = BannerTemplate::where('course_id', $id)->where('banner_type', 'bottom')->orderby('banner_order', 'ASC')->get();
        $coursesubjects = CourseSubject::where('course_id', $id)->orderby('subject_order', 'ASC')->get();
        $courseplan = CoursePlan::where('course_id', $id)->orderby('id', 'desc')->get();

        $additional = AdditionalCourse::where('course_id', $id)->orderby('id', 'ASC')->get();

        $referrer = Referrer::where('course_id', $id)->first();
        $referee = Referee::where('course_id', $id)->first();

        $plantype = PlanType::select('id', 'name')->where('status', '1')->orderby('id', 'DESC')->get();
        $helpUrl = HelpUrl::select('help_url_free', 'help_url_paid')->where('course_id', $id)->first();
        
        $courseReferralLink = CourseReferralLink::select('referral_link')->where('course_id', $id)->first();


        // //dd($course);
        return view('backend.student-dashboard.index', compact('id', 'topbanners', 'bottombanners', 'coursesubjects', 'courseplan', 'additional', 'referrer', 'referee', 'plantype', 'helpUrl', 'courseReferralLink'));
    }




    public function top_banner_create($id)
    {
        $banner_template = BannerTemplate::select('id','banner_name')->where(['course_id'=> null,'subject_id'=> null,'chapter_id'=>null,'subject_template_id'=>null,'chapter_template_id'=>null,'banner_type'=>'top'])->orderby('id', 'desc')->get();

        $plantype = PlanType::select('id', 'name')->where('status', '1')->orderby('id', 'DESC')->get();
        return view('backend.student-dashboard.topbanner.create', compact('id', 'plantype','banner_template'));
    }





    public function bottom_banner_create($id)
    {
        $banner_template = BannerTemplate::select('id','banner_name')->where(['course_id'=> null,'subject_id'=> null,'chapter_id'=>null,'subject_template_id'=>null,'chapter_template_id'=>null,'banner_type'=>'bottom'])->orderby('id', 'desc')->get();

        $plantype = PlanType::select('id', 'name')->where('status', '1')->orderby('id', 'DESC')->get();
        return view('backend.student-dashboard.bottombanner.create', compact('id', 'plantype', 'banner_template'));
    }

    public function bottom_banner_order($courseid,$id)
    {
        $count = BannerTemplate::where(['course_id'=> $courseid,'banner_order'=> $id,'banner_type'=> 'bottom'])->count();
        return $count;
    }

    public function top_banner_store(Request $request)
    {
        //dd($request);
        if(isset($request->banner_template_id) && !empty($request->banner_template_id)){
            $banner_template = BannerTemplate::where('id', $request->banner_template_id)->first();
            //dd($bannertemplate);
            if($banner_template){
                $banner_last = BannerTemplate::select('id','banner_order')->where(['course_id'=>$request->course_id,'banner_type'=>$request->banner_type])->orderby('id', 'desc')->first();   
                if($banner_last){
                    $banner_order = $banner_last->banner_order+1;
                }else{
                    $banner_order = 1;
                }
                $banner = new BannerTemplate;
                $banner->banner_order = $banner_order;
                $banner->banner_name = $banner_template->banner_name;
                $banner->banner_image = $banner_template->banner_image;
                $banner->banner_type = $banner_template->banner_type;
                $banner->banner_function = $banner_template->banner_function;
                $banner->banner_link = $banner_template->banner_link;
                $banner->banner_display = $banner_template->banner_display;
                $banner->course_id = $request->course_id;
                if($banner->save()){
                    return redirect()->route('backend.studentdashboard.index', $request->course_id)->with('success', 'Record Import successfully!');
                }
            }
        }else{
            $validator = Validator::make($request->all(), [
                'banner_order' => 'required',
                'banner_name' => 'required',
                'banner_image' => 'required',
                'banner_type' => 'required',
                'course_id' => 'required',
    
            ]);
            if ($validator->fails()) {
                return redirect()->route('backend.studentdashboard.index')
                    ->with('error', $validator->errors()->first());
            }    
            $banner = new BannerTemplate;
            $banner->banner_order = $request->banner_order;
            $banner->banner_name = $request->banner_name;
            $banner->banner_image = $request->banner_image;
            $banner->banner_type = $request->banner_type;
            $banner->banner_function = $request->banner_function;
            $banner->banner_link = $request->banner_link;
            $banner->banner_display = serialize($request->banner_display);
            $banner->course_id = $request->course_id;
            $banner->save();
            return redirect()->route('backend.studentdashboard.index', $request->course_id)
                ->with('success', 'Banner successfully created');
        }        

    }

    public function top_banner_edit($id)
    {
        $plantype = PlanType::select('id', 'name')->where('status', '1')->orderby('id', 'DESC')->get();
        $banner = BannerTemplate::find($id);
        return view('backend.student-dashboard.topbanner.edit', compact('banner', 'plantype'));
    }

    public function bottom_banner_edit($id)
    {
        $plantype = PlanType::select('id', 'name')->where('status', '1')->orderby('id', 'DESC')->get();
        $banner = BannerTemplate::find($id);
        return view('backend.student-dashboard.bottombanner.edit', compact('banner', 'plantype'));

    }

    public function top_banner_update(Request $request, $id)
    {
        // dd($request);

        $validator = Validator::make($request->all(), [
            'banner_order' => 'required',
            'banner_name' => 'required',
            'banner_image' => 'required',
            'banner_type' => 'required',
        ]);
        if ($validator->fails()) {
            return redirect()->route('backend.studentdashboard.index')
                ->with('error', $validator->errors()->first());
        }

        $banner = BannerTemplate::find($id);
        $banner->banner_order = $request->banner_order;
        $banner->banner_name = $request->banner_name;
        $banner->banner_image = $request->banner_image;
        $banner->banner_type = $request->banner_type;
        $banner->banner_function = $request->banner_function;
        $banner->banner_link = $request->banner_link;
        $banner->banner_display = serialize($request->banner_display);
        $banner->course_id = $request->course_id;

        $banner->save();
        // return redirect()->back();
        return redirect()->route('backend.studentdashboard.index', $request->course_id)
            ->with('success', 'Banner successfully updated');
    }


    public function top_banner_status(BannerTemplate $id, $status)
    {
        //dd($id);
        if ($id) {
            $id->status = $status;
            $id->save();
            return redirect()->back()
                ->with('success', 'banner staus successfully updated');
        }
    }


    public function top_banner_delete(BannerTemplate $id)
    {
        //dd($id);
        if ($id) {
            $id->delete();
            return redirect()->back()
                ->with('success', 'banner deleted');
        }
    }

    public function banner_order($courseid,$id)
    {
        $count = BannerTemplate::where(['course_id'=> $courseid,'banner_order'=> $id,'banner_type'=> 'top'])->count();
        //$aacount = BannerTemplate::where(['course_id'=> $courseid,'banner_order'=> $id,'banner_type'=> 'bottom'])->count();

        return $count;
    }



    // SubjectTemplate start



    public function subject_create($id)
    {
        $subject_templates = SubjectTemplate::select('subject_id', 'subject_display_name')->where('status', '1')->orderby('id', 'desc')->get();

        $subject_category = SubjectCategory::select('id','name')->where('status','1')->orderby('id', 'desc')->get();

        return view('backend.student-dashboard.subject.create', compact('id', 'subject_templates', 'subject_category'));
    }

    public function subject_store(Request $request)
    {
        //dd($request);
        if(isset($request->subject_template_id) && !empty($request->subject_template_id)){
            
            $subject_template = SubjectTemplate::with('subjecttemplatechapter','subjecttemplatechapter.coursesubjectchapterpdf','subjecttemplatechapter.coursesubjectchapterbanner','subjecttemplatechapter.coursesubjectchapterseperator','subjecttemplatebanner','subjecttemplateseperator')->where('subject_id', $request->subject_template_id)->first();
            if($subject_template){
                //dd($subject_template);
                //new id increment
                $course_subject = CourseSubject::select('subject_id')->where('subject_id','like','%ST-%')->orderby('id', 'desc')->first();
                if($course_subject){
                    $id_array = explode('-',$course_subject->subject_id);
                    $id_num = $id_array['1'];
                    $incrementedNumber = str_pad((int)$id_num + 1, strlen($id_num), '0', STR_PAD_LEFT);
                    $course_subject_id = 'ST-'.$incrementedNumber;
                }else{
                    $course_subject_id = 'ST-001';
                }

                //order increment
                $course_subject_order_last = CourseSubject::select('subject_order')->where('course_id',$request->course_id)->orderby('subject_order', 'desc')->first();
                if($course_subject_order_last){
                    $course_subject_order = $course_subject_order_last->subject_order+1;
                }else{
                    $course_subject_order = 1;
                }

                $subject = new CourseSubject;
                $subject->subject_id = $course_subject_id;
                $subject->subject_order = $course_subject_order;
                $subject->subject_display_name = $subject_template['subject_display_name'];
                $subject->subject_categary_id = $subject_template['subject_categary_id'];
                $subject->subject_type = $subject_template['subject_type'];
                $subject->top_text=$subject_template['top_text'];
                $subject->link=$subject_template['link'];
                $subject->var_a=$subject_template['var_a'];
                $subject->var_b=$subject_template['var_b'];
                $subject->var_c=$subject_template['var_c'];

                $subject->course_id = $request->course_id;
                if($subject->save()){
                    //dd($subject);

                    //add banner
                    if($subject_template['subjecttemplatebanner']){
                        //dd($subject_template['subjecttemplatebanner']);
                        foreach($subject_template['subjecttemplatebanner'] as $value){
                            // $banner_last = BannerTemplate::select('banner_order')->where('subject_id',$subject->subject_id)->orderby('id', 'desc')->first();
                            // if($banner_last){
                            //     $banner_order = $banner_last->banner_order+1;                                
                            // }else{
                            //     $banner_order = 1;
                            // }
                            
                            // if($value->banner_type == 'middle'){
                            //     $banner_order_last = BannerTemplate::select('banner_order')->where(['subject_id'=>$subject->subject_id,'banner_type'=>'middle'])->orderby('banner_order','DESC')->first();                            
                            //     if($banner_order_last){
                            //         $number1 = $banner_order_last->banner_order;
                            //     }else{
                            //         $number1 = 0;
                            //     }

                            //     $seperator_order_last = ChapterSeperator::select('seperator_order')->where(['subject_id'=>$subject->subject_id])->orderby('seperator_order','DESC')->first();
                            //     if($seperator_order_last){
                            //         $number2 = $seperator_order_last->seperator_order;
                            //     }else{
                            //         $number2 = 0;
                            //     }

                            //     $chapter_order_last = CourseSubjectChapter::select('chapter_order')->where(['course_subject_id'=>$subject->subject_id])->orderby('chapter_order','DESC')->first();
                            //     if($chapter_order_last){
                            //         $number3 = $chapter_order_last->chapter_order;
                            //     }else{
                            //         $number3 = 0;
                            //     }

                            //     if ($number1 >= $number2 && $number1 >= $number3) {
                            //         $banner_order = $number1 + 1;
                            //     } elseif ($number2 >= $number1 && $number2 >= $number3) {
                            //         $banner_order = $number2 + 1;
                            //     } else {
                            //         $banner_order = $number3 + 1;
                            //     }
                            // }else{
                            //     $banner_last = BannerTemplate::select('banner_order')->where(['banner_type'=>'bottom','subject_id'=>$subject->subject_id])->orderby('id', 'desc')->first();
                            //     if($banner_last){
                            //         $banner_order = $banner_last->banner_order+1;                                
                            //     }else{
                            //         $banner_order = 1;
                            //     }
                            // }
                            

                            $banner = new BannerTemplate;
                            $banner->banner_order = $value->banner_order;
                            $banner->banner_name = $value->banner_name;
                            $banner->banner_image = $value->banner_image;
                            $banner->banner_type = $value->banner_type;
                            $banner->banner_function = $value->banner_function;
                            $banner->banner_link = $value->banner_link;
                            $banner->banner_display = $value->banner_display;
                            $banner->subject_id = $subject->subject_id;
                            $banner->save();
                        }
                    }

                    //add seperator
                    if($subject_template['subjecttemplateseperator']){
                        foreach($subject_template['subjecttemplateseperator'] as $value){
                            // $seperator_last = ChapterSeperator::select('seperator_order')->where('subject_id',$subject->subject_id)->orderby('id', 'desc')->first();
                            // if($seperator_last){
                            //     $seperator_order = $seperator_last->seperator_order+1;
                            // }else{
                            //     $seperator_order = 1;
                            // }

                            // $banner_order_last = BannerTemplate::select('banner_order')->where(['subject_id'=>$subject->subject_id,'banner_type'=>'middle'])->orderby('banner_order','DESC')->first();                            
                            // if($banner_order_last){
                            //     $number1 = $banner_order_last->banner_order;
                            // }else{
                            //     $number1 = 0;
                            // }

                            // $seperator_order_last = ChapterSeperator::select('seperator_order')->where(['subject_id'=>$subject->subject_id])->orderby('seperator_order','DESC')->first();
                            // if($seperator_order_last){
                            //     $number2 = $seperator_order_last->seperator_order;
                            // }else{
                            //     $number2 = 0;
                            // }

                            // $chapter_order_last = CourseSubjectChapter::select('chapter_order')->where(['course_subject_id'=>$subject->subject_id])->orderby('chapter_order','DESC')->first();
                            // if($chapter_order_last){
                            //     $number3 = $chapter_order_last->chapter_order;
                            // }else{
                            //     $number3 = 0;
                            // }

                            // if ($number1 >= $number2 && $number1 >= $number3) {
                            //     $seperator_order = $number1 + 1;
                            // } elseif ($number2 >= $number1 && $number2 >= $number3) {
                            //     $seperator_order = $number2 + 1;
                            // } else {
                            //     $seperator_order = $number3 + 1;
                            // }

                            $seperator = new ChapterSeperator;
                            $seperator->seperator_order = $value->seperator_order;
                            $seperator->seperator_display_text = $value->seperator_display_text;
                            $seperator->subject_id = $subject->subject_id;
                            $seperator->save();
                        }
                    }

                    //add chapter
                    if($subject_template['subjecttemplatechapter']){
                        foreach($subject_template['subjecttemplatechapter'] as $value){
                            //dd($value);
                            // $course_subject_chapter_last = CourseSubjectChapter::select('id','chapter_id','chapter_order')->orderby('id', 'desc')->first();
                            // if($course_subject_chapter_last){
                            //     $course_subject_chapter_id = 'CH-'.$course_subject_chapter_last->id.'-'.rand(111,999);
                            //     $course_subject_chapter_order = $course_subject_chapter_last->chapter_order+1;
                            // }else{
                            //     $course_subject_chapter_id = 'CH-001';
                            //     $course_subject_chapter_order = 1;
                            // }

                            //new id increment
                            $course_subject_chapter_last = CourseSubjectChapter::select('chapter_id')->where('chapter_id','like','STCH-%')->orderby('id', 'desc')->first();
                            if($course_subject_chapter_last){
                                //dd($course_subject_chapter_last);
                                $id_array = explode('-',$course_subject_chapter_last->chapter_id);
                                $id_num = $id_array['1'];
                                $incrementedNumber = str_pad((int)$id_num + 1, strlen($id_num), '0', STR_PAD_LEFT);
                                $course_subject_chapter_id = 'STCH-'.$incrementedNumber;
                            }else{ 
                                $course_subject_chapter_id = 'STCH-001';
                            }

                            // $banner_order_last = BannerTemplate::select('banner_order')->where(['subject_id'=>$subject->subject_id,'banner_type'=>'middle'])->orderby('banner_order','DESC')->first();                            
                            // if($banner_order_last){
                            //     $number1 = $banner_order_last->banner_order;
                            // }else{
                            //     $number1 = 0;
                            // }

                            // $seperator_order_last = ChapterSeperator::select('seperator_order')->where(['subject_id'=>$subject->subject_id])->orderby('seperator_order','DESC')->first();
                            // if($seperator_order_last){
                            //     $number2 = $seperator_order_last->seperator_order;
                            // }else{
                            //     $number2 = 0;
                            // }

                            // $chapter_order_last = CourseSubjectChapter::select('chapter_order')->where(['course_subject_id'=>$subject->subject_id])->orderby('chapter_order','DESC')->first();
                            // if($chapter_order_last){
                            //     $number3 = $chapter_order_last->chapter_order;
                            // }else{
                            //     $number3 = 0;
                            // }

                            // if ($number1 >= $number2 && $number1 >= $number3) {
                            //     $course_subject_chapter_order = $number1 + 1;
                            // } elseif ($number2 >= $number1 && $number2 >= $number3) {
                            //     $course_subject_chapter_order = $number2 + 1;
                            // } else {
                            //     $course_subject_chapter_order = $number3 + 1;
                            // }

                            $subject_chapter = new CourseSubjectChapter;
                            $subject_chapter->chapter_id = $course_subject_chapter_id;
                            $subject_chapter->chapter_order = $value->chapter_order;
                            $subject_chapter->chapter_name = (!empty($value->chapter_name))?$value->chapter_name:null;
                            $subject_chapter->top_text = (!empty($value->top_text))?$value->top_text:null;
                            $subject_chapter->link = (!empty($value->link))?$value->link:null;
                            // $subject_chapter->var_a = (!empty($value->var_a))?$value->var_a:null;
                            // $subject_chapter->var_b = (!empty($value->var_b))?$value->var_b:null;
                            // $subject_chapter->var_c = (!empty($value->var_c))?$value->var_c:null;
                            $subject_chapter->course_subject_id = $subject->subject_id;
                            $subject_chapter->status = $value->status;
                            if($subject_chapter->save()){
                                //dd($value);
                                if($value['coursesubjectchapterpdf']){
                                    foreach($value['coursesubjectchapterpdf'] as $pdfvalue){
                                        // $course_subject_chapter_pdf_last = Pdf::select('order')->orderby('id', 'desc')->first();
                                        // if($course_subject_chapter_pdf_last){
                                        //     $course_subject_chapter_pdf_order = $course_subject_chapter_pdf_last->order+1;
                                        // }else{
                                        //     $course_subject_chapter_pdf_order = 1;
                                        // }

                                        //get order start  
                                        // $banner_order_last = BannerTemplate::select('banner_order')->where(['chapter_id'=>$subject_chapter->chapter_id,'banner_type'=>'middle','pdf_item_type'=>$pdfvalue->pdf_item_type])->orderby('banner_order','DESC')->first();                            
                                        // if($banner_order_last){
                                        //     $number1 = $banner_order_last->banner_order;
                                        // }else{
                                        //     $number1 = 0;
                                        // }

                                        // $seperator_order_last = ChapterSeperator::select('seperator_order')->where(['chapter_id'=>$subject_chapter->chapter_id,'pdf_item_type'=>$pdfvalue->pdf_item_type])->orderby('seperator_order','DESC')->first();
                                        // if($seperator_order_last){
                                        //     $number2 = $seperator_order_last->seperator_order;
                                        // }else{
                                        //     $number2 = 0;
                                        // }

                                        // $pdf_order_last = Pdf::select('order')->where(['chapter_id'=>$subject_chapter->chapter_id,'pdf_item_type'=>$pdfvalue->pdf_item_type])->orderby('order','DESC')->first();
                                        // if($pdf_order_last){
                                        //     $number3 = $pdf_order_last->order;
                                        // }else{
                                        //     $number3 = 0;
                                        // }

                                        // if ($number1 >= $number2 && $number1 >= $number3) {
                                        //     $course_subject_chapter_pdf_order = $number1 + 1;
                                        // } elseif ($number2 >= $number1 && $number2 >= $number3) {
                                        //     $course_subject_chapter_pdf_order = $number2 + 1;
                                        // } else {
                                        //     $course_subject_chapter_pdf_order = $number3 + 1;
                                        // }                                            

                                        $subject_chapter_pdf = new Pdf;
                                        $subject_chapter_pdf->order = $pdfvalue->order;
                                        $subject_chapter_pdf->pdf_name = (!empty($pdfvalue->pdf_name))?$pdfvalue->pdf_name:null;
                                        $subject_chapter_pdf->pdf_type = (!empty($pdfvalue->pdf_type))?$pdfvalue->pdf_type:null;
                                        $subject_chapter_pdf->pdf_link = (!empty($pdfvalue->pdf_link))?$pdfvalue->pdf_link:null;
                                        $subject_chapter_pdf->pdf_link_prefix = (!empty($pdfvalue->pdf_link_prefix))?$pdfvalue->pdf_link_prefix:null;
                                        $subject_chapter_pdf->pdf_link_suflix = (!empty($pdfvalue->pdf_link_suflix))?$pdfvalue->pdf_link_suflix:null;
                                        $subject_chapter_pdf->access = (!empty($pdfvalue->access))?$pdfvalue->access:null;
                                        $subject_chapter_pdf->top_text = (!empty($pdfvalue->top_text))?$pdfvalue->top_text:null;
                                        $subject_chapter_pdf->link = (!empty($pdfvalue->link))?$pdfvalue->link:null;
                                        $subject_chapter_pdf->pdf_item_type = (!empty($pdfvalue->pdf_item_type))?$pdfvalue->pdf_item_type:null;
                                        $subject_chapter_pdf->chapter_id = $subject_chapter->chapter_id;
                                        $subject_chapter_pdf->status = $pdfvalue->status;
                                        $subject_chapter_pdf->save();
                                    }
                                }   

                                //chapter banner
                                //dd($value['coursesubjectchapterbanner']);
                                if($value['coursesubjectchapterbanner']){
                                    foreach($value['coursesubjectchapterbanner'] as $bannervalue){                                       

                                        // if($bannervalue->banner_type == 'middle'){
                                        //    //get order start  
                                        //     $banner_order_last = BannerTemplate::select('banner_order')->where(['chapter_id'=>$subject_chapter->chapter_id,'banner_type'=>'middle','pdf_item_type'=>$bannervalue->pdf_item_type])->orderby('banner_order','DESC')->first();                            
                                        //     if($banner_order_last){
                                        //         $number1 = $banner_order_last->banner_order;
                                        //     }else{
                                        //         $number1 = 0;
                                        //     }

                                        //     $seperator_order_last = ChapterSeperator::select('seperator_order')->where(['chapter_id'=>$subject_chapter->chapter_id,'pdf_item_type'=>$bannervalue->pdf_item_type])->orderby('seperator_order','DESC')->first();
                                        //     if($seperator_order_last){
                                        //         $number2 = $seperator_order_last->seperator_order;
                                        //     }else{
                                        //         $number2 = 0;
                                        //     }

                                        //     $pdf_order_last = Pdf::select('order')->where(['chapter_id'=>$subject_chapter->chapter_id,'pdf_item_type'=>$bannervalue->pdf_item_type])->orderby('order','DESC')->first();
                                        //     if($pdf_order_last){
                                        //         $number3 = $pdf_order_last->order;
                                        //     }else{
                                        //         $number3 = 0;
                                        //     }

                                        //     if ($number1 >= $number2 && $number1 >= $number3) {
                                        //         $banner_order = $number1 + 1;
                                        //     } elseif ($number2 >= $number1 && $number2 >= $number3) {
                                        //         $banner_order = $number2 + 1;
                                        //     } else {
                                        //         $banner_order = $number3 + 1;
                                        //     }
                                        // }else{
                                        //     $banner_last = BannerTemplate::where(['chapter_id'=>$subject_chapter->chapter_id,'banner_type'=>'bottom','pdf_item_type'=>$bannervalue->pdf_item_type])->first();
                                        //     if($banner_last){
                                        //         $banner_order = $banner_last->banner_order+1;
                                        //     }else{
                                        //         $banner_order = 1;
                                        //     }
                                        // }

                                        $chapterbanner = new BannerTemplate;
                                        $chapterbanner->banner_order = $bannervalue->banner_order;
                                        $chapterbanner->banner_name = $bannervalue->banner_name;
                                        $chapterbanner->banner_image = $bannervalue->banner_image;
                                        $chapterbanner->banner_type = $bannervalue->banner_type;
                                        $chapterbanner->banner_function = $bannervalue->banner_function;
                                        $chapterbanner->banner_link = $bannervalue->banner_link;
                                        $chapterbanner->banner_display = $bannervalue->banner_display;
                                        $chapterbanner->pdf_item_type = $bannervalue->pdf_item_type;
                                        $chapterbanner->chapter_id = $subject_chapter->chapter_id;
                                        $chapterbanner->save();
                                    }
                                }

                                //chapter sepretor
                                if($value['coursesubjectchapterseperator']){
                                    foreach($value['coursesubjectchapterseperator'] as $seperatorvalue){
                                        // $seperator_last = ChapterSeperator::select('seperator_order')->where('chapter_id',$subject_chapter->chapter_id)->orderby('id', 'desc')->first();
                                        // if($seperator_last){
                                        //     $seperator_order = $seperator_last->seperator_order+1;
                                        // }else{
                                        //     $seperator_order = 1;
                                        // }

                                        //get order start  
                                        // $banner_order_last = BannerTemplate::select('banner_order')->where(['chapter_id'=>$subject_chapter->chapter_id,'banner_type'=>'middle','pdf_item_type'=>$seperatorvalue->pdf_item_type])->orderby('banner_order','DESC')->first();                            
                                        // if($banner_order_last){
                                        //     $number1 = $banner_order_last->banner_order;
                                        // }else{
                                        //     $number1 = 0;
                                        // }

                                        // $seperator_order_last = ChapterSeperator::select('seperator_order')->where(['chapter_id'=>$subject_chapter->chapter_id,'pdf_item_type'=>$seperatorvalue->pdf_item_type])->orderby('seperator_order','DESC')->first();
                                        // if($seperator_order_last){
                                        //     $number2 = $seperator_order_last->seperator_order;
                                        // }else{
                                        //     $number2 = 0;
                                        // }

                                        // $pdf_order_last = Pdf::select('order')->where(['chapter_id'=>$subject_chapter->chapter_id,'pdf_item_type'=>$seperatorvalue->pdf_item_type])->orderby('order','DESC')->first();
                                        // if($pdf_order_last){
                                        //     $number3 = $pdf_order_last->order;
                                        // }else{
                                        //     $number3 = 0;
                                        // }

                                        // if ($number1 >= $number2 && $number1 >= $number3) {
                                        //     $seperator_order = $number1 + 1;
                                        // } elseif ($number2 >= $number1 && $number2 >= $number3) {
                                        //     $seperator_order = $number2 + 1;
                                        // } else {
                                        //     $seperator_order = $number3 + 1;
                                        // }

                                        $seperator = new ChapterSeperator;
                                        $seperator->seperator_order = $seperatorvalue->seperator_order;
                                        $seperator->seperator_display_text = $seperatorvalue->seperator_display_text;
                                        $seperator->pdf_item_type = $seperatorvalue->pdf_item_type;
                                        $seperator->chapter_id = $subject_chapter->chapter_id;
                                        $seperator->save();
                                    }
                                }
                            }
                        }
                    }
                    //dd($subject_template);
                    return redirect()->route('backend.studentdashboard.index', $request->course_id)->with('success', 'Record Import successfully!');
                }
            }
        }else{
            $validator = Validator::make($request->all(), [
                'subject_order' => 'required',
                'subject_id' => 'required',
                'subject_display_name' => 'required',
                'subject_categary_id' => 'required',
            ]);
            if ($validator->fails()) {
                return redirect()->route('backend.studentdashboard.index', $request->course_id)
                    ->with('error', $validator->errors()->first());
            }

            $subject = new CourseSubject;
            $subject->subject_order = $request->subject_order;
            $subject->subject_id = $request->subject_id;
            $subject->subject_display_name = $request->subject_display_name;
            $subject->subject_categary_id=$request->subject_categary_id;
            $subject->subject_type=$request->subject_type;
            $subject->top_text=$request->top_text;
            $subject->link=$request->link;
            $subject->var_a=$request->var_a;
            $subject->var_b=$request->var_b;
            $subject->var_c=$request->var_c;

            $subject->course_id = $request->course_id;

            $subject->save();
            
            // return redirect()->back();
            return redirect()->route('backend.studentdashboard.index', $request->course_id)
            ->with('success', 'subject successfully create');
        }

    }


    public function subject_edit($id)
    {
        $subject_category = SubjectCategory::select('id','name')->where('status','1')->orderby('id', 'desc')->get();

        $subject = CourseSubject::find($id);
        return view('backend.student-dashboard.subject.edit', compact('subject','subject_category'));

    }



    public function subject_update(Request $request, $id)
    {


        $validator = Validator::make($request->all(), [

            'subject_order' => 'required',
            'subject_id' => 'required',
            'subject_display_name' => 'required',
            'subject_categary_id' => 'required',

        ]);
        if ($validator->fails()) {
            return redirect()->route('backend.studentdashboard.index')
                ->with('error', $validator->errors()->first());
        }

        $subject = CourseSubject::find($id);
        $subject->subject_order = $request->subject_order;
        $subject->subject_id = $request->subject_id;
        $subject->subject_display_name = $request->subject_display_name;
        $subject->subject_categary_id=$request->subject_categary_id;
        $subject->subject_type=$request->subject_type;
        
        $subject->top_text=$request->top_text;
        $subject->link=$request->link;
        $subject->var_a=$request->var_a;
        $subject->var_b=$request->var_b;
        $subject->var_c=$request->var_c;
        $subject->course_id = $request->course_id;


        $subject->save();
        // return redirect()->back();
        return redirect()->route('backend.studentdashboard.index', $request->course_id)
            ->with('success', 'subject successfully updated');

    }

    public function subject_status(CourseSubject $id, $status)
    {
        //dd($id);
        if ($id) {
            $id->status = $status;
            $id->save();
            return redirect()->back()
                ->with('success', 'banner staus successfully updated');
        }
    }


    public function subject_delete(CourseSubject $id)
    {
        //dd($id);
        if ($id) {
            $id->delete();
            return redirect()->back()
                ->with('success', 'banner deleted');
        }
    }


    public function subject_order($id, $order){
        $subject_count = CourseSubject::where(['course_id'=>$id,'subject_order'=>$order])->count();
        return $subject_count;
    }
    // SubjectTemplate end 


    // Add Plan Template Statrt

    public function plan_create($id)
    {
        $plantype = PlanType::select('id', 'name')->where('status', '1')->orderby('id', 'DESC')->get();
        return view('backend.student-dashboard.plans.create', compact('id','plantype'));
    }


    public function plan_store(Request $request)
    {
        // dd($request);

        $validator = Validator::make($request->all(), [
            'plan_name' => 'required',
            'plan_validity' => 'required',
            'plan_type' => 'required',
            'androide_price' => 'required',
            'ios_price' => 'required',
            'discount' => 'required',
            'gst' => 'required',
            'discount_validity' => 'required',
            'plan_image' => 'required',
            'plan_multicouurse' => 'required',
            'confirmation_page' => 'required',
            'mail' => 'required',
            'course_id' => 'required',

        ]);
        if ($validator->fails()) {
            return redirect()->route('backend.studentdashboard.index', $request->course_id)
                ->with('error', $validator->errors()->first());
        }

        $plans = new CoursePlan;
        $plans->plan_name = $request->plan_name;
        $plans->plan_validity = $request->plan_validity;
        $plans->plan_type = $request->plan_type;
        $plans->androide_price = $request->androide_price;
        $plans->ios_price = $request->ios_price;
        $plans->discount = $request->discount;
        $plans->gst = $request->gst;
        $plans->discount_validity = $request->discount_validity;
        $plans->plan_image = $request->plan_image;
        $plans->plan_multicouurse = $request->plan_multicouurse;
        $plans->confirmation_page = $request->confirmation_page;
        $plans->mail = $request->mail;
        $plans->course_id = $request->course_id;
        $plans->save();
        return redirect()->route('backend.studentdashboard.index', $request->course_id)
            ->with('success', 'Plan successfully created');

    }


    public function plan_edit($id)
    {
        $plantype = PlanType::select('id', 'name')->where('status', '1')->orderby('id', 'DESC')->get();
        $plans = CoursePlan::find($id);
        return view('backend.student-dashboard.plans.edit', compact('plans','plantype'));

    }


    public function plan_update(Request $request, $id)
    {
        // dd($request);

        $validator = Validator::make($request->all(), [
            'plan_name' => 'required',
            'plan_validity' => 'required',
            'plan_type' => 'required',
            'androide_price' => 'required',
            'ios_price' => 'required',
            'discount' => 'required',
            'gst' => 'required',
            'discount_validity' => 'required',
            'plan_image' => 'required',
            'plan_multicouurse' => 'required',
            'confirmation_page' => 'required',
            'mail' => 'required',
            'course_id' => 'required',

        ]);
        if ($validator->fails()) {
            return redirect()->route('backend.studentdashboard.index')
                ->with('error', $validator->errors()->first());
        }

        $plans = CoursePlan::find($id);
        $plans->plan_name = $request->plan_name;
        $plans->plan_validity = $request->plan_validity;
        $plans->plan_type = $request->plan_type;
        $plans->androide_price = $request->androide_price;
        $plans->ios_price = $request->ios_price;
        $plans->discount = $request->discount;
        $plans->gst = $request->gst;
        $plans->discount_validity = $request->discount_validity;
        $plans->plan_image = $request->plan_image;
        $plans->plan_multicouurse = $request->plan_multicouurse;
        $plans->confirmation_page = $request->confirmation_page;
        $plans->mail = $request->mail;
        $plans->course_id = $request->course_id;
        $plans->save();
        return redirect()->route('backend.studentdashboard.index', $request->course_id)
            ->with('success', 'Plan successfully updated');

    }


    public function plan_status(CoursePlan $id, $status)
    {
        //dd($id);
        if ($id) {
            $id->status = $status;
            $id->save();
            return redirect()->back()
                ->with('success', 'plan staus successfully updated');
        }
    }




    public function plan_delete(CoursePlan $id)
    {
        //dd($id);
        if ($id) {
            $id->delete();
            return redirect()->back()
                ->with('success', 'banner deleted');
        }
    }



    public function addtional_Order($id)
    {
        $count = CoursePlan::where('addtional_order', $id)->count();
        return $count;
    }

    // Add Plan Template end

    // start additional Course

    public function additional_create($id)
    {
        $additional_course_templates = AdditionalCourse::select('AC_ID', 'course_name')->where('status', '1')->orderby('id', 'desc')->get();

        $additional_templates = AdditionalCourseTemplate::select('course_id', 'course_name')->where('status', '1')->orderby('id', 'desc')->get();

        return view('backend.student-dashboard.additional.create', compact('id','additional_course_templates','additional_templates'));
    }



    public function additional_store(Request $request)
    {
        //dd($request);
        if(isset($request->additional_course_template_id) && !empty($request->additional_course_template_id)){
            $additional_course_template = AdditionalCourseTemplate::with('additionaltemplatesubject','additionaltemplatesubject.additionaltemplatesubjectchapter','additionaltemplatesubject.additionaltemplatesubjectbanner','additionaltemplatesubject.additionaltemplatesubjectseperator','additionaltemplatesubject.additionaltemplatesubjectchapter.additionaltemplatesubjectchapterpdf','additionaltemplatesubject.additionaltemplatesubjectchapter.additionaltemplatesubjectchapterbanner','additionaltemplatesubject.additionaltemplatesubjectchapter.additionaltemplatesubjectchapterseperator')->where('course_id', $request->additional_course_template_id)->first();
            //dd($additional_course_template);
            if($additional_course_template){
                // $additional_course = AdditionalCourse::select('id','AC_ID','AC_ORDER')->orderby('id', 'desc')->first();
                // //dd($additional_course);
                // if($additional_course){
                //     $course_id = 'AT-'.$additional_course->id.'-'.rand(111,999);
                //     $course_order = $additional_course->AC_ORDER+1;
                // }else{
                //     $course_id = 'AT-001';
                //     $course_order = 1;
                // }

                //new id increment
                $course_last = AdditionalCourse::select('AC_ID')->where('AC_ID','like','AT-%')->orderby('id', 'desc')->first();
                if($course_last){
                    $id_array = explode('-',$course_last->AC_ID);
                    $id_num = $id_array['1'];
                    $incrementedNumber = str_pad((int)$id_num + 1, strlen($id_num), '0', STR_PAD_LEFT);
                    $course_id = 'AT-'.$incrementedNumber;
                }else{
                    $course_id = 'AT-001';
                }

                //order increment
                $course_order_last = AdditionalCourse::select('AC_ORDER')->where('course_id',$request->course_id)->orderby('AC_ORDER', 'desc')->first();
                if($course_order_last){
                    $course_order = $course_order_last->AC_ORDER+1;   
                }else{
                    $course_order = 1;
                }

                $course = new AdditionalCourse;
                $course->AC_ID = $course_id;
                $course->AC_ORDER = $course_order;
                $course->course_name = $additional_course_template['course_name'];
                $course->course_id = $request->course_id;
                if($course->save()){
                    //dd($course);
                    if($additional_course_template['additionaltemplatesubject']){
                        foreach($additional_course_template['additionaltemplatesubject'] as $value){
                            //dd($value);
                            // $course_subject_last = AdditionalCourseSubject::select('id','subject_id','subject_order')->orderby('id', 'desc')->first();
                            // //dd($course_subject_last);
                            // if($course_subject_last){
                            //     $course_subject_id = 'S-'.$course_subject_last->id.'-'.rand(111,999);
                            //     $course_subject_order = $course_subject_last->subject_order+1;
                            // }else{
                            //     $course_subject_id = 'S-01';
                            //     $course_subject_order = 1;
                            // }

                            //new id increment
                            $course_subject_last = AdditionalCourseSubject::select('subject_id')->where('subject_id','like','ATS-%')->orderby('id', 'desc')->first();
                            if($course_subject_last){
                                $id_array = explode('-',$course_subject_last->subject_id);
                                $id_num = $id_array['1'];
                                $incrementedNumber = str_pad((int)$id_num + 1, strlen($id_num), '0', STR_PAD_LEFT);
                                $course_subject_id = 'ATS-'.$incrementedNumber;
                            }else{
                                $course_subject_id = 'ATS-001';
                            }

                            //order increment
                            // $course_subject_order_last = AdditionalCourseSubject::select('subject_order')->where('additional_course_id',$course->AC_ID)->orderby('subject_order', 'desc')->first();
                            // if($course_subject_order_last){
                            //     $course_subject_order = $course_subject_order_last->subject_order+1;   
                            // }else{
                            //     $course_subject_order = 1;
                            // }

                            $course_subject = new AdditionalCourseSubject;
                            $course_subject->subject_id = $course_subject_id;
                            $course_subject->subject_order = $value->subject_order;
                            $course_subject->subject_display_name = (!empty($value->subject_display_name))?$value->subject_display_name:null;
                            $course_subject->subject_categary_id = (!empty($value->subject_categary_id))?$value->subject_categary_id:null;

                            $course_subject->top_text=$value['top_text'];
                            $course_subject->link=$value['link'];
                            $course_subject->var_a=$value['var_a'];
                            $course_subject->var_b=$value['var_b'];
                            $course_subject->var_c=$value['var_c'];

                            $course_subject->additional_course_id = $course->AC_ID;
                            $course_subject->status = $value->status;
                            if($course_subject->save()){
                                //dd($course_subject);
                                if($value['additionaltemplatesubjectchapter']){
                                    foreach($value['additionaltemplatesubjectchapter'] as $chaptervalue){
                                        // $course_subject_chapter_last = AdditionalCourseSubjectChapter::select('id','chapter_order')->orderby('id', 'desc')->first();
                                        // if($course_subject_chapter_last){
                                        //     $course_subject_chapter_id = 'S-'.$course_subject_chapter_last->id.'-'.rand(111,999);
                                        //     $course_subject_chapter_order = $course_subject_chapter_last->chapter_order+1;
                                        // }else{
                                        //     $course_subject_chapter_id = 'C-01';
                                        //     $course_subject_chapter_order = 1;
                                        // }


                                        //new id increment
                                        $course_subject_chapter_last = AdditionalCourseSubjectChapter::select('chapter_id')->where('chapter_id','like','ATSC-%')->orderby('id', 'desc')->first();
                                        if($course_subject_chapter_last){
                                            $id_array = explode('-',$course_subject_chapter_last->chapter_id);
                                            $id_num = $id_array['1'];
                                            $incrementedNumber = str_pad((int)$id_num + 1, strlen($id_num), '0', STR_PAD_LEFT);
                                            $course_subject_chapter_id = 'ATSC-'.$incrementedNumber;
                                        }else{
                                            $course_subject_chapter_id = 'ATSC-001';
                                        }

                                        //order increment
                                        // $course_subject_chapter_order_last = AdditionalCourseSubjectChapter::select('chapter_order')->orderby('chapter_order', 'desc')->first();
                                        // if($course_subject_chapter_order_last){
                                        //     $course_subject_chapter_order = $course_subject_chapter_order_last->chapter_order+1;   
                                        // }else{
                                        //     $course_subject_chapter_order = 1;
                                        // }


                                        // $banner_order_last = AdditionalBanner::select('banner_order')->where(['subject_id'=>$course_subject->subject_id,'banner_type'=>'middle'])->orderby('banner_order','DESC')->first();                            
                                        // if($banner_order_last){
                                        //     $number1 = $banner_order_last->banner_order;
                                        // }else{
                                        //     $number1 = 0;
                                        // }
            
                                        // $seperator_order_last = AdditionalSeperator::select('seperator_order')->where(['subject_id'=>$course_subject->subject_id])->orderby('seperator_order','DESC')->first();
                                        // if($seperator_order_last){
                                        //     $number2 = $seperator_order_last->seperator_order;
                                        // }else{
                                        //     $number2 = 0;
                                        // }
            
                                        // $chapter_order_last = AdditionalCourseSubjectChapter::select('chapter_order')->where(['additional_course_subject_id'=>$course_subject->subject_id])->orderby('chapter_order','DESC')->first();
                                        // if($chapter_order_last){
                                        //     $number3 = $chapter_order_last->chapter_order;
                                        // }else{
                                        //     $number3 = 0;
                                        // }
            
                                        // if ($number1 >= $number2 && $number1 >= $number3) {
                                        //     $course_subject_chapter_order = $number1 + 1;
                                        // } elseif ($number2 >= $number1 && $number2 >= $number3) {
                                        //     $course_subject_chapter_order = $number2 + 1;
                                        // } else {
                                        //     $course_subject_chapter_order = $number3 + 1;
                                        // }


                                        $subject_chapter = new AdditionalCourseSubjectChapter;
                                        $subject_chapter->chapter_id = $course_subject_chapter_id;
                                        $subject_chapter->chapter_order = $chaptervalue->chapter_order;
                                        $subject_chapter->chapter_name = (!empty($chaptervalue->chapter_name))?$chaptervalue->chapter_name:null;
                                        $subject_chapter->top_text = (!empty($chaptervalue->top_text))?$chaptervalue->top_text:null;
                                        $subject_chapter->link = (!empty($chaptervalue->link))?$chaptervalue->link:null;
                                        // $subject_chapter->var_a = (!empty($chaptervalue->var_a))?$chaptervalue->var_a:null;
                                        // $subject_chapter->var_b = (!empty($chaptervalue->var_b))?$chaptervalue->var_b:null;
                                        // $subject_chapter->var_c = (!empty($chaptervalue->var_c))?$chaptervalue->var_c:null;
                                        $subject_chapter->additional_course_subject_id = $course_subject->subject_id;
                                        $subject_chapter->status = $chaptervalue->status;
                                        if($subject_chapter->save()){
                                            //dd($subject_chapter);
                                            //dd($chaptervalue);
                                            if($chaptervalue['additionaltemplatesubjectchapterpdf']){
                                                foreach($chaptervalue['additionaltemplatesubjectchapterpdf'] as $pdfvalue){
                                                    // $course_subject_chapter_pdf_last = AdditionalCourseSubjectChapterPdf::select('order')->orderby('id', 'desc')->first();
                                                    // if($course_subject_chapter_pdf_last){
                                                    //     $course_subject_chapter_pdf_order = $course_subject_chapter_pdf_last->order+1;
                                                    // }else{
                                                    //     $course_subject_chapter_pdf_order = 1;
                                                    // }

                                                    // $banner_order_last = AdditionalBanner::select('banner_order')->where(['chapter_id'=>$subject_chapter->chapter_id,'banner_type'=>'middle','pdf_item_type'=>$pdfvalue->item_type])->orderby('banner_order','DESC')->first();

                                                    // if($banner_order_last){
                                                    //     $number1 = $banner_order_last->banner_order;
                                                    // }else{
                                                    //     $number1 = 0;
                                                    // }

                                                    // $seperator_order_last = AdditionalSeperator::select('seperator_order')->where(['chapter_id'=>$subject_chapter->chapter_id,'pdf_item_type'=>$pdfvalue->item_type])->orderby('seperator_order','DESC')->first();
                                                    // if($seperator_order_last){
                                                    //     $number2 = $seperator_order_last->seperator_order;
                                                    // }else{
                                                    //     $number2 = 0;
                                                    // }

                                                    // $pdf_order_last = AdditionalCourseSubjectChapterPdf::select('order')->where(['chapter_id'=>$subject_chapter->chapter_id,'item_type'=>$pdfvalue->item_type])->orderby('order','DESC')->first();
                                                    // if($pdf_order_last){
                                                    //     $number3 = $pdf_order_last->order;
                                                    // }else{
                                                    //     $number3 = 0;
                                                    // }

                                                    // if ($number1 >= $number2 && $number1 >= $number3) {
                                                    //     $course_subject_chapter_pdf_order = $number1 + 1;
                                                    // } elseif ($number2 >= $number1 && $number2 >= $number3) {
                                                    //     $course_subject_chapter_pdf_order = $number2 + 1;
                                                    // } else {
                                                    //     $course_subject_chapter_pdf_order = $number3 + 1;
                                                    // }

                                                    $subject_chapter_pdf = new AdditionalCourseSubjectChapterPdf;
                                                    $subject_chapter_pdf->order = $pdfvalue->order;
                                                    $subject_chapter_pdf->pdf_name = (!empty($pdfvalue->pdf_name))?$pdfvalue->pdf_name:null;
                                                    $subject_chapter_pdf->pdf_type = (!empty($pdfvalue->pdf_type))?$pdfvalue->pdf_type:null;
                                                    $subject_chapter_pdf->pdf_link = (!empty($pdfvalue->pdf_link))?$pdfvalue->pdf_link:null;
                                                    $subject_chapter_pdf->pdf_link_prefix = (!empty($pdfvalue->pdf_link_prefix))?$pdfvalue->pdf_link_prefix:null;
                                                    $subject_chapter_pdf->pdf_link_suflix = (!empty($pdfvalue->pdf_link_suflix))?$pdfvalue->pdf_link_suflix:null;
                                                    $subject_chapter_pdf->access = (!empty($pdfvalue->access))?$pdfvalue->access:null;
                                                    $subject_chapter_pdf->top_text = (!empty($pdfvalue->top_text))?$pdfvalue->top_text:null;
                                                    $subject_chapter_pdf->link = (!empty($pdfvalue->link))?$pdfvalue->link:null;
                                                    $subject_chapter_pdf->item_type = (!empty($pdfvalue->item_type))?$pdfvalue->item_type:null;
                                                    $subject_chapter_pdf->chapter_id = $subject_chapter->chapter_id;
                                                    $subject_chapter_pdf->status = $pdfvalue->status;
                                                    $subject_chapter_pdf->save();
                                                    //dd($subject_chapter_pdf);
                                                }
                                            }

                                            //chapter banner
                                            if($chaptervalue['additionaltemplatesubjectchapterbanner']){
                                                foreach($chaptervalue['additionaltemplatesubjectchapterbanner'] as $bannervalue){
                                                    // if($bannervalue->banner_type == 'middle'){
                                                    //     $banner_order_last = AdditionalBanner::select('banner_order')->where(['chapter_id'=>$subject_chapter->chapter_id,'banner_type'=>'middle','pdf_item_type'=>$bannervalue->pdf_item_type])->orderby('banner_order','DESC')->first();

                                                    //     if($banner_order_last){
                                                    //         $number1 = $banner_order_last->banner_order;
                                                    //     }else{
                                                    //         $number1 = 0;
                                                    //     }

                                                    //     $seperator_order_last = AdditionalSeperator::select('seperator_order')->where(['chapter_id'=>$subject_chapter->chapter_id,'pdf_item_type'=>$bannervalue->pdf_item_type])->orderby('seperator_order','DESC')->first();
                                                    //     if($seperator_order_last){
                                                    //         $number2 = $seperator_order_last->seperator_order;
                                                    //     }else{
                                                    //         $number2 = 0;
                                                    //     }

                                                    //     $pdf_order_last = AdditionalCourseSubjectChapterPdf::select('order')->where(['chapter_id'=>$subject_chapter->chapter_id,'item_type'=>$bannervalue->pdf_item_type])->orderby('order','DESC')->first();
                                                    //     if($pdf_order_last){
                                                    //         $number3 = $pdf_order_last->order;
                                                    //     }else{
                                                    //         $number3 = 0;
                                                    //     }

                                                    //     if ($number1 >= $number2 && $number1 >= $number3) {
                                                    //         $banner_order = $number1 + 1;
                                                    //     } elseif ($number2 >= $number1 && $number2 >= $number3) {
                                                    //         $banner_order = $number2 + 1;
                                                    //     } else {
                                                    //         $banner_order = $number3 + 1;
                                                    //     }
                                                    // }else{
                                                    //     $banner_last = AdditionalBanner::select('banner_order')->where(['chapter_id'=>$subject_chapter->chapter_id,'pdf_item_type'=>$bannervalue->item_type,'banner_type'=>'bottom'])->orderby('banner_order', 'DESC')->first();
                                                    //     if($banner_last){
                                                    //         $banner_order = $banner_last->banner_order+1;
                                                    //     }else{
                                                    //         $banner_order = 1;
                                                    //     }
                                                    // }
                                                    
                                                    $banner = new AdditionalBanner;
                                                    $banner->banner_order = $bannervalue->banner_order;
                                                    $banner->banner_name = $bannervalue->banner_name;
                                                    $banner->banner_image = $bannervalue->banner_image;
                                                    $banner->banner_type = $bannervalue->banner_type;
                                                    $banner->banner_function = $bannervalue->banner_function;
                                                    $banner->banner_link = $bannervalue->banner_link;
                                                    $banner->banner_display = $bannervalue->banner_display;
                                                    $banner->pdf_item_type = $bannervalue->pdf_item_type;
                                                    $banner->chapter_id = $subject_chapter->chapter_id;
                                                    $banner->save();
                                                }
                                            }

                                            //chapter sepretor
                                            if($chaptervalue['additionaltemplatesubjectchapterseperator']){
                                                foreach($chaptervalue['additionaltemplatesubjectchapterseperator'] as $seperatorvalue){
                                                    // $seperator_last = AdditionalSeperator::select('seperator_order')->where('chapter_id',$subject_chapter->chapter_id)->orderby('id', 'desc')->first();
                                                    // if($seperator_last){
                                                    //     $seperator_order = $seperator_last->seperator_order+1;
                                                    // }else{
                                                    //     $seperator_order = 1;
                                                    // }
                                                    // $banner_order_last = AdditionalBanner::select('banner_order')->where(['chapter_id'=>$subject_chapter->chapter_id,'banner_type'=>'middle','pdf_item_type'=>$seperatorvalue->pdf_item_type])->orderby('banner_order','DESC')->first();

                                                    // if($banner_order_last){
                                                    //     $number1 = $banner_order_last->banner_order;
                                                    // }else{
                                                    //     $number1 = 0;
                                                    // }

                                                    // $seperator_order_last = AdditionalSeperator::select('seperator_order')->where(['chapter_id'=>$subject_chapter->chapter_id,'pdf_item_type'=>$seperatorvalue->pdf_item_type])->orderby('seperator_order','DESC')->first();
                                                    // if($seperator_order_last){
                                                    //     $number2 = $seperator_order_last->seperator_order;
                                                    // }else{
                                                    //     $number2 = 0;
                                                    // }

                                                    // $pdf_order_last = AdditionalCourseSubjectChapterPdf::select('order')->where(['chapter_id'=>$subject_chapter->chapter_id,'item_type'=>$seperatorvalue->pdf_item_type])->orderby('order','DESC')->first();
                                                    // if($pdf_order_last){
                                                    //     $number3 = $pdf_order_last->order;
                                                    // }else{
                                                    //     $number3 = 0;
                                                    // }

                                                    // if ($number1 >= $number2 && $number1 >= $number3) {
                                                    //     $seperator_order = $number1 + 1;
                                                    // } elseif ($number2 >= $number1 && $number2 >= $number3) {
                                                    //     $seperator_order = $number2 + 1;
                                                    // } else {
                                                    //     $seperator_order = $number3 + 1;
                                                    // }
                                                    $seperator = new AdditionalSeperator;
                                                    $seperator->seperator_order = $seperatorvalue->seperator_order;
                                                    $seperator->seperator_display_text = $seperatorvalue->seperator_display_text;
                                                    $seperator->pdf_item_type = $seperatorvalue->pdf_item_type;
                                                    $seperator->chapter_id = $subject_chapter->chapter_id;
                                                    $seperator->save();
                                                }
                                            }
                                        }
                                    }
                                }
                                if($value['additionaltemplatesubjectbanner']){
                                    foreach($value['additionaltemplatesubjectbanner'] as $bannervalue){
                                        //if($bannervalue->banner_type == 'middle'){

                                        //     $banner_order_last = AdditionalBanner::select('banner_order')->where(['subject_id'=>$course_subject->subject_id,'banner_type'=>'middle'])->orderby('banner_order','DESC')->first();                            
                                        //     if($banner_order_last){
                                        //         $number1 = $banner_order_last->banner_order;
                                        //     }else{
                                        //         $number1 = 0;
                                        //     }
                
                                        //     $seperator_order_last = AdditionalSeperator::select('seperator_order')->where(['subject_id'=>$course_subject->subject_id])->orderby('seperator_order','DESC')->first();
                                        //     if($seperator_order_last){
                                        //         $number2 = $seperator_order_last->seperator_order;
                                        //     }else{
                                        //         $number2 = 0;
                                        //     }
                
                                        //     $chapter_order_last = AdditionalCourseSubjectChapter::select('chapter_order')->where(['additional_course_subject_id'=>$course_subject->subject_id])->orderby('chapter_order','DESC')->first();
                                        //     if($chapter_order_last){
                                        //         $number3 = $chapter_order_last->chapter_order;
                                        //     }else{
                                        //         $number3 = 0;
                                        //     }
                
                                        //     if ($number1 >= $number2 && $number1 >= $number3) {
                                        //         $banner_order = $number1 + 1;
                                        //     } elseif ($number2 >= $number1 && $number2 >= $number3) {
                                        //         $banner_order = $number2 + 1;
                                        //     } else {
                                        //         $banner_order = $number3 + 1;
                                        //     }
                                        // }else{
                                        //     $banner_last = AdditionalBanner::select('banner_order')->where(['subject_id'=>$course_subject->subject_id,'banner_type'=>'bottom'])->orderby('id', 'desc')->first();
                                        //     if($banner_last){
                                        //         $banner_order = $banner_last->banner_order+1;
                                        //     }else{
                                        //         $banner_order = 1;
                                        //     }
                                        // }
                                        $banner = new AdditionalBanner;
                                        $banner->banner_order = $bannervalue->banner_order;
                                        $banner->banner_name = $bannervalue->banner_name;
                                        $banner->banner_image = $bannervalue->banner_image;
                                        $banner->banner_type = $bannervalue->banner_type;
                                        $banner->banner_function = $bannervalue->banner_function;
                                        $banner->banner_link = $bannervalue->banner_link;
                                        $banner->banner_display = $bannervalue->banner_display;
                                        $banner->subject_id = $course_subject->subject_id;
                                        $banner->save();
                                    }
                                }
                                //chapter sepretor
                                if($value['additionaltemplatesubjectseperator']){
                                    foreach($value['additionaltemplatesubjectseperator'] as $seperatorvalue){
                                        // $seperator_last = AdditionalSeperator::select('seperator_order')->where('subject_id',$course_subject->subject_id)->orderby('id', 'desc')->first();
                                        // if($seperator_last){
                                        //     $seperator_order = $seperator_last->seperator_order+1;
                                        // }else{
                                        //     $seperator_order = 1;
                                        // }

                                        // $banner_order_last = AdditionalBanner::select('banner_order')->where(['subject_id'=>$course_subject->subject_id,'banner_type'=>'middle'])->orderby('banner_order','DESC')->first();
                                        // if($banner_order_last){
                                        //     $number1 = $banner_order_last->banner_order;
                                        // }else{
                                        //     $number1 = 0;
                                        // }
            
                                        // $seperator_order_last = AdditionalSeperator::select('seperator_order')->where(['subject_id'=>$course_subject->subject_id])->orderby('seperator_order','DESC')->first();
                                        // if($seperator_order_last){
                                        //     $number2 = $seperator_order_last->seperator_order;
                                        // }else{
                                        //     $number2 = 0;
                                        // }
            
                                        // $chapter_order_last = AdditionalCourseSubjectChapter::select('chapter_order')->where(['additional_course_subject_id'=>$course_subject->subject_id])->orderby('chapter_order','DESC')->first();
                                        // if($chapter_order_last){
                                        //     $number3 = $chapter_order_last->chapter_order;
                                        // }else{
                                        //     $number3 = 0;
                                        // }
            
                                        // if ($number1 >= $number2 && $number1 >= $number3) {
                                        //     $seperator_order = $number1 + 1;
                                        // } elseif ($number2 >= $number1 && $number2 >= $number3) {
                                        //     $seperator_order = $number2 + 1;
                                        // } else {
                                        //     $seperator_order = $number3 + 1;
                                        // }

                                        $seperator = new AdditionalSeperator;
                                        $seperator->seperator_order = $seperatorvalue->seperator_order;
                                        $seperator->seperator_display_text = $seperatorvalue->seperator_display_text;
                                        $seperator->subject_id = $course_subject->subject_id;
                                        $seperator->save();
                                    }
                                }
                            }
                        }
                    }
                    //dd($subject_template);
                    return redirect()->route('backend.studentdashboard.index', $request->course_id)->with('success', 'Record Import successfully!');
                }
            }
        }else{         

            $validator = Validator::make($request->all(), [
                'AC_ORDER' => 'required',
                'AC_ID' => 'required',
                'course_name' => 'required',
            ]);
            if ($validator->fails()) {
                return redirect()->route('backend.studentdashboard.index')
                    ->with('error', $validator->errors()->first());
            }

            $additional = new AdditionalCourse;
            $additional->AC_ORDER = $request->AC_ORDER;
            $additional->AC_ID = $request->AC_ID;
            $additional->course_name = $request->course_name;
            $additional->course_id = $request->course_id;
            $additional->save();
            return redirect()->route('backend.studentdashboard.index', $request->course_id)
                ->with('success', 'additional Course successfully created');
        }
    }

    public function additional_edit($id)
    {
        $additional = AdditionalCourse::find($id);
        return view('backend.student-dashboard.additional.edit', compact('additional'));

    }



    public function additional_update(Request $request, $id)
    {
        // dd($request);

        $validator = Validator::make($request->all(), [
            'AC_ORDER' => 'required',
            'AC_ID' => 'required',
            'course_name' => 'required',

        ]);
        if ($validator->fails()) {
            return redirect()->route('backend.studentdashboard.index')
                ->with('error', $validator->errors()->first());
        }

        $additional = AdditionalCourse::find($id);
        $additional->AC_ORDER = $request->AC_ORDER;
        $additional->AC_ID = $request->AC_ID;
        $additional->course_name = $request->course_name;
        $additional->course_id = $request->course_id;
        $additional->save();
        return redirect()->route('backend.studentdashboard.index', $request->course_id)
            ->with('success', 'additional successfully updated');
    }



    public function additional_status(AdditionalCourse $id, $status)
    {
        //dd($id);
        if ($id) {
            $id->status = $status;
            $id->save();
            return redirect()->back()
                ->with('success', 'additional staus successfully updated');
        }
    }


    public function additional_delete(AdditionalCourse $id)
    {
        //dd($id);
        if ($id) {
            $id->delete();
            return redirect()->back()
                ->with('success', 'additional deleted');
        }
    }




    public function additional_Order($id)
    {
        $count = AdditionalCourse::where('AC_ORDER', $id)->count();
        return $count;
    }


    // end additional Course


    // start referrer


    public function referrer_store(Request $request)
    {
        //dd($request);

        $validator = Validator::make($request->all(), [
            'delay_day' => 'required',
            'plan_type' => 'required',
          //  'validity_day' => 'required',
            'number' => 'required',
            'status' => 'required',

        ]);
        if ($validator->fails()) {
            return redirect()->back()
                ->with('error', $validator->errors()->first());
        }

        // $Referrer = new Referrer;
        // $Referrer->delay_day=$request->delay_day;
        // $Referrer->plan_type=$request->plan_type;
        // $Referrer->validity_day=$request->validity_day;
        // $Referrer->no=$request->no;
        // $Referrer->status=$request->status;
        // $Referrer->course_id=$request->course_id;
        // $Referrer->save();


        $referrer = Referrer::updateOrCreate(
            [
                'course_id' => $request->course_id
            ],
            [
                'delay_day' => $request->delay_day,
                'plan_type' => $request->plan_type,
                'validity_day' => 0,
                'number' => $request->number,
                'course_id' => $request->course_id,
                'status' => $request->status,
            ]
        );

        return redirect()->back()
            ->with('success', 'Referrer successfully created');

    }

    // end referrer
// start referee
    public function referee_store(Request $request)
    {
        // dd($request);

        $validator = Validator::make($request->all(), [
            // 'delay_day' => 'required',
            'plan_type' => 'required',
            'validity_day' => 'required',
            'status' => 'required',
            // 'course_id' => $request->course_id,
        ]);
        if ($validator->fails()) {
            return redirect()->back()
                ->with('error', $validator->errors()->first());
        }

        // $Referee = new Referee;
        // $Referee->delay_day=$request->delay_day;
        // $Referee->plan_type=$request->plan_type;
        // $Referee->validity_day=$request->validity_day;
        // $Referee->status=$request->status;
        // $Referee->course_id=$request->course_id;
        // $Referee->save();


        $referee = Referee::updateOrCreate(
            [
                'course_id' => $request->course_id
            ],
            [
                'delay_day' => 0,                         // $request->delay_day,
                'plan_type' => $request->plan_type,
                'validity_day' => $request->validity_day,
                'status' => $request->status,
                'course_id' => $request->course_id,

            ]
        );






        return redirect()->back()
            ->with('success', 'Referee successfully created');

    }

    // end referee
    
     public function free_help_url_store(Request $request)
    {
        // dd($request);

        $validator = Validator::make($request->all(), [
            'help_url_free' => 'required',
        ]);
        if ($validator->fails()) {
            return redirect()->back()
                ->with('error', $validator->errors()->first());
        }

        $helpUrl = HelpUrl::updateOrCreate(
            [
                'course_id' => $request->course_id
            ],
            [
                'help_url_free' => $request->help_url_free,
            ]
        );

         return redirect()->back()
            ->with('success', 'Url successfully created');

    }


    public function paid_help_url_store(Request $request)
    {
        // dd($request);

        $validator = Validator::make($request->all(), [
            'help_url_paid' => 'required',
        ]);
        if ($validator->fails()) {
            return redirect()->back()
                ->with('error', $validator->errors()->first());
        }

        $helpUrl = HelpUrl::updateOrCreate(
            [
                'course_id' => $request->course_id
            ],
            [
                'help_url_paid' => $request->help_url_paid,
            ]
        );

         return redirect()->back()
            ->with('success', 'Url successfully created');

    }
    
     public function course_referral_link_store(Request $request)
    {
        // dd($request);

        $validator = Validator::make($request->all(), [
            'course_id' => 'required',
            'referral_link' => 'required'
        ]);
        if ($validator->fails()) {
            return redirect()->back()
                ->with('error', $validator->errors()->first());
        }

        $courseReferralLink = CourseReferralLink::updateOrCreate(
            [
                'course_id' => $request->course_id
            ],
            [
                'referral_link' => $request->referral_link,
            ]
        );

         return redirect()->back()
            ->with('success', 'Referral Url successfully created');

    }

}