<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\UserStudentProfilePlan;
use App\Models\PlanType;
use App\Models\Setting;
use App\Models\Transaction;

use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Image;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Auth;

class TransactionsController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index(Request $request)
    {
        $limit = $request->limit ? $request->limit : 10;
        $pageNumber = $request->page ? $request->page : 1;
        $serialnum = ($pageNumber - 1) * $limit + 1;
        $userlist = [];
        $totalRecords = Transaction::whereIn('order_status', ['VERIFIED', 'DONE'])
                                ->orderby('id', 'desc')
                                ->count();
       

        $totalPages = ceil($totalRecords / $limit);

        if ($pageNumber>0 && $pageNumber <= $totalPages) {
            $offset = ($pageNumber - 1) * $limit;
            $transaction_list = Transaction::whereIn('order_status', ['VERIFIED', 'DONE'])
            ->orderby('id', 'desc')
            ->offset($offset)
            ->limit($limit)
            ->get();
            $transactionsWithPlans = $transaction_list->map(function ($transaction) {
                // Fetch the plan details based on the user_email
                $plan = UserStudentProfilePlan::where(['user_email'=> $transaction->user_email,'course_id'=>$transaction->course_id])->first();
    
                // Add plan details to the transaction object
                $transaction->plan_name = $plan ? $plan->plan_name : 'N/A';
                $transaction->validity_of_plan = $plan ? $plan->validity_of_plan : 'N/A';
                
                 $createdatetime = new \DateTime($transaction->created_at, new \DateTimeZone('UTC'));
                 $createdatetime->setTimezone(new \DateTimeZone('Asia/Kolkata')); 
                 $createdAt = $createdatetime->format('d-m-Y H:i:s');
                 
                 $updatedatetime = new \DateTime($transaction->updated_at, new \DateTimeZone('UTC'));
                 $updatedatetime->setTimezone(new \DateTimeZone('Asia/Kolkata')); 
                 $updatedAt = $updatedatetime->format('d-m-Y H:i:s');
                 
                 
                $transaction->created_at = $createdAt ? $createdAt : 'N/A';
                $transaction->updated_at = $updatedAt ? $updatedAt : 'N/A';
                 
    
                return $transaction;
            });
            
        } else {
            return redirect()->back()->with('error', "No more records");
        }
        
        if (!$transactionsWithPlans || $transactionsWithPlans->isEmpty()) {
            return redirect()->back()->with('error', "No more records");
        }

        return view('backend.transactions.index',compact('transactionsWithPlans','limit', 'serialnum', 'totalRecords', 'totalPages', 'pageNumber'));
    }
    public function search(Request $request){
        $transactions=Transaction::whereIn('order_status', ['VERIFIED', 'DONE'])
            ->where(function($query) use ($request) {
                $keyword = $request->keyword;
                $query->orWhereRaw("SUBSTRING_INDEX(user_email, '@', 1) LIKE ?", ['%' . $keyword . '%']);
            })
            ->get();
        $transactions_list = $transactions->map(function ($transaction) {
            // Fetch the plan details based on the user_email
            $plan = UserStudentProfilePlan::where(['user_email'=> $transaction->user_email,'course_id'=>$transaction->course_id])->first();

            // Add plan details to the transaction object
            $transaction->plan_name = $plan ? $plan->plan_name : 'N/A';
            $transaction->validity_of_plan = $plan ? $plan->validity_of_plan : 'N/A';

            return $transaction;
        });
        
        if(!$transactions_list || $transactions_list->isEmpty()){
                return redirect()->back()
                    ->with('error',"No records found for keyword ".$request->keyword );
        }
        $keyword=$request->keyword;
        return view('backend.transactions.search', compact('transactions_list','keyword'));
    }

    
}