<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\UserReferral;
use App\Models\CoursePlan;
use App\Models\UserStudentProfilePlan;
use App\Models\PlanType;
use App\Models\Setting;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Image;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Auth;

class UsersController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index(Request $request)
    {
        $limit = $request->limit ? $request->limit : 25;
        $pageNumber = $request->page ? $request->page : 1;
        $serialnum = ($pageNumber - 1) * $limit + 1;
        $userlist = [];
        $totalRecords = User::where('profile_one_type','STUDENT')->count();
        $totalPages = ceil($totalRecords / $limit);

        if ($pageNumber>0 && $pageNumber <= $totalPages) {
            $offset = ($pageNumber - 1) * $limit;
            $userlist = User::where('profile_one_type','STUDENT')->orderBy('id', 'asc')
            ->offset($offset)
            ->limit($limit)
            ->get();
        } else {
            return redirect()->back()->with('error', "No more records");
        }

        if (!$userlist || $userlist->isEmpty()) {
            return redirect()->back()->with('error', "No more records");
        }

        return view('backend.users.index', compact('userlist', 'limit', 'serialnum', 'totalRecords', 'totalPages', 'pageNumber'));
    }


    public function search(Request $request){
        $userlist = User::where('profile_one_type', 'STUDENT')->where(function($query) use ($request) {
            $keyword = $request->keyword;
            $query->where('name', 'like', '%' . $keyword . '%')
                  ->orWhereRaw("SUBSTRING_INDEX(email, '@', 1) LIKE ?", ['%' . $keyword . '%']);
        })
        ->get();
        if(!$userlist || $userlist->isEmpty()){
                return redirect()->back()
                    ->with('error',"No records found for keyword ".$request->keyword );
        }
        $keyword=$request->keyword;
        return view('backend.users.search', compact('userlist','keyword'));
    }
    public function info(Request $request,$userid){
        $user = User::select('id', 'name', 'email', 'referral_code_valid', 'referral_applide_date', 'profile_one', 'profile_two', 'is_onboarded', 'last_active_profile', 'referral_id', 'last_login', 'profile_one_type', 'profile_two_type', 'number_of_referrals', 'email_verified_at', 'role','user_blocked',   'status', 'created_at', 'updated_at', 'deleted_at', 'last_active')->find($userid);
        $number_of_referrals=UserReferral::where('user_email',$user->email)->value('num_referrals');

        $user_student_profile_plan_one=null;
        $profile_one_course_plan=null;
        $user_student_profile_plan_two=null;
        $profile_two_course_plan=null;
        $course_plans_profile_two_list=null;
        $course_plans_profile_one_list=null;

        if($user->profile_one=='true'){
            $user_student_profile_plan_one=UserStudentProfilePlan::where(['user_email'=>$user->email,'profile_number'=>'PROFILE_ONE'])->first();
            if($user_student_profile_plan_one)
                $profile_one_course_plan=CoursePlan::where('course_id',$user_student_profile_plan_one->course_id)->first();
            $course_plans_profile_one_list=CoursePlan::where(['status'=>'1','course_id'=>$user_student_profile_plan_one->course_id])->get();
           
            
        }
            
        if($user->profile_two=='true'){
            $user_student_profile_plan_two=UserStudentProfilePlan::where(['user_email'=>$user->email,'profile_number'=>'PROFILE_TWO'])->first();
            if($user_student_profile_plan_two)
                $profile_two_course_plan=CoursePlan::where('course_id',$user_student_profile_plan_two->course_id)->first();
            $course_plans_profile_two_list=CoursePlan::where(['status'=>'1','course_id'=>$user_student_profile_plan_two->course_id])->get();
        }
          
        $datetime = new \DateTime($user->last_active, new \DateTimeZone('UTC'));
        $datetime->setTimezone(new \DateTimeZone('Asia/Kolkata')); // Adjust to IST
        // Format the datetime in IST
        $lastactive = $datetime->format('d-m-Y H:i:s');
        $datetime = new \DateTime($user->created_at, new \DateTimeZone('UTC'));
        $datetime->setTimezone(new \DateTimeZone('Asia/Kolkata')); // Adjust to IST
        // Format the datetime in IST
        $createdat = $datetime->format('d-m-Y H:i:s');
    
        return view('backend.users.info', compact('user','number_of_referrals','user_student_profile_plan_two','user_student_profile_plan_one','course_plans_profile_one_list','course_plans_profile_two_list','lastactive','createdat'));

    }

    public function updateplan(Request $request){

        try{
            $profileOnePlanId=$request->profileOnePlanId;
            $profileTwoPlanId=$request->profileTwoPlanId;
            $userId=$request->userId;

            if($profileOnePlanId>=0){
                $student=User::find($userId);
                $studentProfile=UserStudentProfilePlan::where(['user_email'=>$student->email,'profile_number'=>'PROFILE_ONE'])->first();
                if($profileOnePlanId!=0){
                    $coursePlan=CoursePlan::find($profileOnePlanId);
                    if($coursePlan){
                        $studentProfile->plan_id=$coursePlan->id;
                        $studentProfile->plan_name=$coursePlan->plan_name;
                        $time = strtotime($coursePlan->plan_validity);
                        $newformat = date('Y-m-d',$time);
                        $studentProfile->validity_of_plan=$newformat;
                        $studentProfile->plan_type=PlanType::where('id',$coursePlan->plan_type)->value('name');
                        $studentProfile->save();
                    }
                }
                else{
                    $studentProfile->plan_id='0';
                    $studentProfile->plan_name=NULL;
                    $studentProfile->validity_of_plan=NULL;
                    $studentProfile->plan_type='free';
                    $studentProfile->save();
                }

            
            }
            if($profileTwoPlanId>=0){
                $student=User::find($userId);
                $studentProfile=UserStudentProfilePlan::where(['user_email'=>$student->email,'profile_number'=>'PROFILE_TWO'])->first();
                if($profileTwoPlanId!=0){
                    $coursePlan=CoursePlan::find($profileTwoPlanId);
                    if($coursePlan){
                        $studentProfile->plan_id=$coursePlan->id;
                        $studentProfile->plan_name=$coursePlan->plan_name;
                        $time = strtotime($coursePlan->plan_validity);
                        $newformat = date('Y-m-d',$time);
                        $studentProfile->validity_of_plan=$newformat;
                        $studentProfile->plan_type=PlanType::where('id',$coursePlan->plan_type)->value('name');
                        $studentProfile->save();
                    }
                }
                else{
                    $studentProfile->plan_id='0';
                    $studentProfile->plan_name=NULL;
                    $studentProfile->validity_of_plan=NULL;
                    $studentProfile->plan_type='free';
                    $studentProfile->save();
                }
            }
            return response("Succcess",200);

        }
        catch (\Exception $e) {
            return response()->json([
                'message' => 'Something Went Wrong!',
                'status' => 500,
                'error' => $e,
            ]);
        }
     
    }

}